# Thymio plugin for Thonny

Plug-in for [Thonny](https://thonny.org/), the _Python IDE for beginners_, to run Python programs on the [Thymio II](https://thymio.org) mobile robot. Based on the module `tdmclient`.
